unit main;

{-------------------------------------------------------------------------------
  main.pas
  hlavni unit demo projektu 'Import'
  2003 (c) manison
-------------------------------------------------------------------------------}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, ComCtrls, ShellAPI, Buttons;

type
  TfmImport = class(TForm)
    trackS: TTrackBar;
    trackL: TTrackBar;
    trackH: TTrackBar;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Image1: TImage;
    lbHue: TLabel;
    lbLuminance: TLabel;
    lbSaturation: TLabel;
    Panel: TPanel;
    Image2: TImage;
    Label4: TLabel;
    Label5: TLabel;
    OpenDialog1: TOpenDialog;
    btBrowse: TButton;
    lbDetails: TLabel;
    Label6: TLabel;
    btCanonicalize: TButton;
    btCombine: TButton;
    edPath: TComboBox;
    btCompact: TButton;
    btGetArgs: TButton;
    btRelative: TButton;
    btIsURL: TButton;
    btParse: TButton;
    btQuote: TButton;
    btMatch: TButton;
    btUnExpand: TButton;
    procedure trackChange(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Image1MouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure Image1MouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure Image1MouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure btBrowseClick(Sender: TObject);
    procedure btCanonicalizeClick(Sender: TObject);
    procedure btCombineClick(Sender: TObject);
    procedure btCompactClick(Sender: TObject);
    procedure btGetArgsClick(Sender: TObject);
    procedure btRelativeClick(Sender: TObject);
    procedure btIsURLClick(Sender: TObject);
    procedure btParseClick(Sender: TObject);
    procedure btQuoteClick(Sender: TObject);
    procedure btMatchClick(Sender: TObject);
    procedure btUnExpandClick(Sender: TObject);
  private
    Color: TColor;
    procedure UpdatePanel;
    procedure UpdateHLS;
  end;

  TAPIPath = array [0..MAX_PATH-1] of AnsiChar;
  TAPIPathW = array [0..MAX_PATH-1] of WideChar;

var
  fmImport: TfmImport;

implementation

{$R *.DFM}

uses Shlwapi;

procedure TfmImport.UpdatePanel;
var
  h, l, s: Word;
  Bitmap: TBitmap;
begin
  Panel.Color := Color;
  Bitmap := TBitmap.Create;
  with Bitmap do begin
    PixelFormat := pf24bit;
    Width := 1;
    Height := 240;
  end;
  ColorRGBToHLS(Color, h, l, s);
  for l := 0 to 240 do
    Bitmap.Canvas.Pixels[0, l] := ColorHLSToRGB(h, l, s);
  StretchBlt(Image2.Picture.Bitmap.Canvas.Handle, 0, 0, 16, 240, Bitmap.Canvas.Handle, 0, 0, 1, 240, SRCCOPY);
  Image2.Refresh;
  Bitmap.Free;
end;

procedure TfmImport.UpdateHLS;
var
  H, L, S: Word;
begin
  ColorRGBToHls(Color, H, L, S);
  trackH.Position := H;
  trackL.Position := L;
  trackS.Position := S;
end;

procedure TfmImport.trackChange(Sender: TObject);
begin
  Color := ColorHLSToRGB(trackH.Position, trackL.Position, trackS.Position);
  lbHue.Caption := IntToStr(trackH.Position);
  lbLuminance.Caption := IntToStr(trackL.Position);
  lbSaturation.Caption := IntToStr(trackS.Position);
  UpdatePanel;
end;

procedure TfmImport.FormCreate(Sender: TObject);
var
  Hue, Saturation: Word;
  Color: TColor;
  Bitmap: TBitmap;
begin
  Bitmap := TBitmap.Create;
  with Bitmap do begin
    PixelFormat := pf24bit;
    Width := 240;
    Height := 240;
  end;
  for Hue := 0 to 240 do begin
    for Saturation := 0 to 240 do begin
      Color := ColorHLSToRGB(Hue, 120, Saturation);
      Bitmap.Canvas.Pixels[Hue, 240-Saturation] := Color;
    end;
  end;
  Image1.Picture.Bitmap.Assign(Bitmap);
  Bitmap.Free;
  with Image2.Picture.Bitmap do begin
    PixelFormat := pf24bit;
    Width := 16;
    Height := 240;
  end;
  UpdatePanel;
end;

procedure TfmImport.Image1MouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
var
  col: TColor;
  h, l, s: Word;
  r: TRect;
begin
  if Button <> mbLeft then Exit;
  r := Image1.ClientRect;
  r.TopLeft := Image1.ClientToScreen(r.TopLeft);
  r.BottomRight := Image1.ClientToScreen(r.BottomRight);
  ClipCursor(@r);
  col := Image1.Picture.Bitmap.Canvas.Pixels[X, Y];
  ColorRGBToHLS(col, h, l, s);
  l := trackL.Position;
  Color := ColorHLSToRGB(h, l, s);
  UpdatePanel;
  UpdateHLS;
end;

procedure TfmImport.Image1MouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);
var
  col: TColor;
  h, l, s: Word;
begin
  if ssLeft in Shift then begin
    col := Image1.Picture.Bitmap.Canvas.Pixels[X, Y];
    ColorRGBToHLS(col, h, l, s);
    l := trackL.Position;
    Color := ColorHLSToRGB(h, l, s);
    UpdatePanel;
    UpdateHLS;
  end;
end;

procedure TfmImport.Image1MouseUp(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  ClipCursor(nil);
end;

procedure TfmImport.btBrowseClick(Sender: TObject);
const
  prolog = 'Velikost souboru ';
  being: array [Boolean] of string = ('nen', 'je');
var
  path: TAPIPath;
  size: array [0..31] of Char;
  time: array [0..31] of Char;
  w: Integer;
  sr: TSearchRec;
begin
  if OpenDialog1.Execute then begin
    edPath.Text := ExtractFilePath(OpenDialog1.FileName);
    StrPCopy(path, OpenDialog1.FileName);
    w := lbDetails.Width - lbDetails.Canvas.TextWidth(prolog);
    PathCompactPath(lbDetails.Canvas.Handle, path, w);
    if FindFirst(OpenDialog1.FileName, $2F, sr) = 0 then
      FindClose(sr)
    else begin
      ShowMessage('Chyba pi otvrn souboru.');
      Exit;
    end;
    StrFormatByteSize(sr.Size, size, Length(size));
    StrFromTimeInterval(time, Length(time), DateTimeToTimeStamp(FileDateToDateTime(sr.Time)).Time, 6);
    lbDetails.Caption := prolog + path + ' je ' + size + ', as poslednho zpisu: ' + time +
      ', soubor '+being[PathIsHTMLFile(PChar(OpenDialog1.FileName))] + ' HTML';
  end;
end;

procedure TfmImport.btCanonicalizeClick(Sender: TObject);
var
  buff: TAPIPath;
begin
  PathCanonicalize(buff, PChar(edPath.Text));
  ShowMessage(buff);
end;

procedure TfmImport.btCombineClick(Sender: TObject);
var
  buff: TAPIPath;
begin
  PathCombine(buff, PChar(edPath.Text), PChar(InputBox(Application.Title, 'Druh cesta ke zkominovn:', 'One\Two\Three')));
  ShowMessage(buff);
end;

procedure TfmImport.btCompactClick(Sender: TObject);
var
  buff: TAPIPath;
begin
  PathCompactPathEx(buff, PChar(edPath.Text), SysUtils.StrToInt(InputBox(Application.Title, 'Maximln dlka:', '20')), 0);
  ShowMessage(buff);
end;

procedure TfmImport.btGetArgsClick(Sender: TObject);
begin
  ShowMessage(PathGetArgs(PChar(edPath.Text)));
end;

procedure TfmImport.btRelativeClick(Sender: TObject);
begin
  if PathIsRelative(PChar(edPath.Text)) then
    ShowMessage('Cesta je relativn.')
  else
    ShowMessage('Cesta nen relativn.');
end;

procedure TfmImport.btIsURLClick(Sender: TObject);
begin
  if PathIsURL(PChar(edPath.Text)) then
    ShowMessage('Cesta je URL.')
  else
    ShowMessage('Cesta nen URL.');
end;

procedure TfmImport.btParseClick(Sender: TObject);
var
  path: TAPIPath;
  index: Integer;
begin
  StrPCopy(path, edPath.Text);
  index := PathParseIconLocation(path);
  ShowMessage(Format('Ikona . %d ze souboru %s.', [index, path]));
end;

procedure TfmImport.btQuoteClick(Sender: TObject);
var
  path: TAPIPath;
begin
  StrPCopy(path, edPath.Text);
  PathQuoteSpaces(path);
  ShowMessage(path);
end;

procedure TfmImport.btMatchClick(Sender: TObject);
begin
  if PathMatchSpec(PChar(edPath.Text), PChar(InputBox(Application.Title, 'Maska:', '*.exe'))) then
    ShowMessage('Cesta odpovd masce.')
  else
    ShowMessage('Cesta neodpovd masce.');
end;

procedure TfmImport.btUnExpandClick(Sender: TObject);
var
  buff: TAPIPath;
begin
  PathUnExpandEnvStrings(PChar(edPath.Text), buff, Length(buff));
  ShowMessage(buff);
end;

end.
